@@ -1,3 +1,5 @@
+# -*- encoding: utf-8 -*-
+
 from unittest import TestCase
 
 import htmlentities
@@ -9,3 +11,7 @@ class EncodingTestCase(TestCase):
         self.assertEqual('&amp;', htmlentities.encode('&'))
         self.assertEqual('&quot;', htmlentities.encode('"'))
         self.assertEqual('&lt;', htmlentities.encode('<'))
+
+    def test_should_encode_utf8_accents(self):
+        self.assertEqual('&eacute;', htmlentities.encode(u'é'))
+        self.assertEqual('&ecirc;', htmlentities.encode(u'ê'))
